;+
; NAME:
;  xdesig
; PURPOSE:
;  Digest and record Minor Planet Center designation cross refereces.
; DESCRIPTION:
;
; CATEGORY:
;  Astrometry
; CALLING SEQUENCE:
;  xdesig,desigfile,objectfile
; INPUTS:
;  desigfile - File name(s) to be read in with cross-references
;  objectfile - File name of master cross references, default='newobj.dat'
; OPTIONAL INPUT PARAMETERS:
;
; KEYWORD INPUT PARAMETERS:
;
; OUTPUTS:
;
; KEYWORD OUTPUT PARAMETERS:
;
; COMMON BLOCKS:
;
; SIDE EFFECTS:
;
; RESTRICTIONS:
;
; PROCEDURE:
;
; MODIFICATION HISTORY:
;  2000 May 3, Written by Marc W. Buie, Lowell Observatory
;-
pro xdesig,fnlist,objectfile

   if badpar(fnlist,7,[0,1],CALLER='XDESIG: (desigfile) ') then return
   if badpar(objectfile,[0,7],0,CALLER='XDESIG: (objectfile) ', $
                default='newobj.dat') then return
   
   ; First see if master file exists.  Quit if no file.
   if not exists(objectfile) then begin
      print,'Master object list file, ',objectfile,' does not exist.  Aborting.'
      return
   endif

   ; Next, make sure input files exist.
   ok=1
   nfiles=n_elements(fnlist)
   for i=0,nfiles-1 do begin
      if not exists(fnlist[i]) then begin
         print,'Input file ',fnlist[i],' does not exist.'
         ok=0
      endif
   endfor
   if not ok then begin
      print,'Aborting.'
      return
   endif

   changed=0

   ; Load the master file
   openr,lun,objectfile,/get_lun
   line=''
   ncodes = 0
   while not eof(lun) do begin
      readf,lun,line,format='(a1)'
      ncodes = ncodes+1
   endwhile
   point_lun,lun,0L
   tab = STRING( byte(9) )
   code=strarr(ncodes)
   disctag=strarr(ncodes)
   info=strarr(ncodes)
   lines=strarr(ncodes)
   for i=0,ncodes-1 do begin
      readf,lun,line,format='(a)'
      lines[i] = line
      words=str_sep(line,tab)
      nwords=n_elements(words)
      code[i] = words[0]
      if nwords ge 2 then disctag[i]=words[1]
      if nwords ge 3 then info[i]=words[2]
   endfor
   free_lun,lun
   print,objectfile,ncodes,' entries.'

   for i=0,nfiles-1 do begin
      first=1
      openr,lun,fnlist[i],/get_lun
      while not eof(lun) do begin
         readf,lun,line,format='(a)'
         line=strtrim(strcompress(line),2)
         words=str_sep(line,' ')
         nwords=n_elements(words)
         if nwords/2*2 ne nwords then begin
            print,fnlist[i],'  [',line,']','  odd number of words.'
         endif else begin
            words=reform(words,2,nwords/2,/overwrite)
            if first then begin
               dlist = words
               first = 0
            endif else begin
               dlist = [[dlist],[words]]
            endelse
         endelse
      endwhile
      free_lun,lun
      ids=dlist[1,*]
      ids=ids[*]
      dlist[1,*] = mpcdcvt(ids)
      dim=size(dlist,/dimen)
      if n_elements(dlist) eq 2 then $
         nlist = 1 $
      else $
         nlist = dim[1]
      print,fnlist[i],nlist,' entries.'
      for j=0,nlist-1 do begin
         z=where(code eq dlist[0,j],count)
         z=z[0]
         if count ne 1 then begin
            print,'Code ',dlist[0,j],' found ',strn(count),' times.'
         endif else begin
            if info[z] eq '' then begin
               changed=1
               info[z] = dlist[1,j]
               lines[z] = code[z]+tab+disctag[z]+tab+info[z]
               print,lines[z]
            endif else begin
               pos=strpos(info[z],dlist[1,j],0)
               if pos lt 0 then begin
                  changed=1
                  info[z] = dlist[1,j]+' '+info[z]
                  lines[z] = code[z]+tab+disctag[z]+tab+info[z]
                  print,lines[z]
               endif else begin
;                  print,'Code ',dlist[0,j],', redundant tag: ',info[z]
               endelse
            endelse
         endelse
      endfor
   endfor

   if changed then begin
      print,'Saving changes to ',objectfile
      openw,lun,objectfile,/get_lun
      for i=0,ncodes-1 do $
         printf,lun,lines[i]
      free_lun,lun
   endif else begin
      print,'No new cross-references, no changes made to ',objectfile
   endelse

end
